@@ -33,13 +33,18 @@ class TestAadict(unittest.TestCase):
     self.assertEqual(d['foo'], 'bar')
 
   #----------------------------------------------------------------------------
-  def test_chaining(self):
+  def test_chaining_update(self):
     d = aadict(foo='bar', zig=87)
     d2 = aadict(x='y').update(d).omit('zig')
     self.assertEqual(d2.x, 'y')
     self.assertEqual(d2.foo, 'bar')
     self.assertIsNone(d2.zig)
 
+  #----------------------------------------------------------------------------
+  def test_chaining_clear(self):
+    d = aadict(foo='bar', zig=87).clear().update(zag='zug')
+    self.assertEqual(d, {'zag': 'zug'})
+
   #----------------------------------------------------------------------------
   def test_convert(self):
     d = aadict.d2ar(dict(foo=dict(bar='zig')))
@@ -58,6 +63,28 @@ class TestAadict(unittest.TestCase):
     self.assertEqual(d2['foo'], 'bar')
     self.assertEqual(d2.foo, 'bar')
 
+  #----------------------------------------------------------------------------
+  def test_dir(self):
+    d1 = dict()
+    d2 = aadict(foo='bar', zig=87)
+    ignore = set(['__weakref__', '__module__', '__dict2aadict__', '__dict__'])
+    self.assertEqual(
+      set(sorted(dir(d2))) - ignore,
+      set(sorted(dir(d1) + [
+        '__getattr__', '__setattr__', '__delattr__', '__dir__',
+        'pick', 'omit', 'd2a', 'd2ar',
+        'foo', 'zig',
+        ])) - ignore)
+
+  #----------------------------------------------------------------------------
+  def test_ctor_cloneupdate(self):
+    d1 = aadict(foo='bar', zig=87)
+    d2 = aadict(d1, zig=99, zag='zog')
+    self.assertEqual(d1, dict(foo='bar', zig=87))
+    self.assertEqual(d2, dict(foo='bar', zig=99, zag='zog'))
+
+
 #------------------------------------------------------------------------------
 # end of $Id$
+# $ChangeLog$
 #------------------------------------------------------------------------------
